<?php

class ControllerExtensionModuleCartToExcel extends Controller {

    const DEFAULT_STATUS = '1';
    const DEFAULT_COLUMN_IMAGE_WIDTH = 30;
    const DEFAULT_COLUMN_NAME_WIDTH = 100;
    const DEFAULT_COLUMN_MODEL_WIDTH = 30;
    const DEFAULT_COLUMN_QUANTITY_WIDTH = 20;
    const DEFAULT_COLUMN_PRICE_WIDTH = 20;
    const DEFAULT_COLUMN_TOTAL_WIDTH = 20;
    const DEFAULT_IMAGE_WIDTH = 50;
    const DEFAULT_IMAGE_HEIGHT = 50;

    private $error = array();

    public function install() {
        $this->load->language('extension/module/cart_to_excel');
        $this->load->model('setting/setting');
        $this->load->model('user/user_group');
        $this->model_user_user_group->addPermission($this->user->getGroupId(), 'access', 'extension/module/cart_to_excel');
        $this->model_user_user_group->addPermission($this->user->getGroupId(), 'modify', 'extension/module/cart_to_excel');
        $default_settings = array(
            'cart_to_excel_status' => self::DEFAULT_STATUS,
            'cart_to_excel_column_image_width' => self::DEFAULT_COLUMN_IMAGE_WIDTH,
            'cart_to_excel_column_name_width' => self::DEFAULT_COLUMN_NAME_WIDTH,
            'cart_to_excel_column_model_width' => self::DEFAULT_COLUMN_MODEL_WIDTH,
            'cart_to_excel_column_quantity_width' => self::DEFAULT_COLUMN_QUANTITY_WIDTH,
            'cart_to_excel_column_price_width' => self::DEFAULT_COLUMN_PRICE_WIDTH,
            'cart_to_excel_column_total_width' => self::DEFAULT_COLUMN_TOTAL_WIDTH,
            'cart_to_excel_image_width' => self::DEFAULT_IMAGE_WIDTH,
            'cart_to_excel_image_height' => self::DEFAULT_IMAGE_HEIGHT,
        );
        $this->model_setting_setting->editSetting('cart_to_excel', $default_settings);
    }

    public function uninstall() {
        $this->load->model('setting/setting');
        $this->model_extension_extension->uninstall('cart_to_excel', $this->request->get['extension']);
        $this->model_setting_setting->deleteSetting($this->request->get['extension']);
    }

    public function index() {
        $this->load->language('extension/module/cart_to_excel');
        $this->load->model('setting/setting');
        if (($this->request->server['REQUEST_METHOD'] == 'POST') && $this->validate()) {
            $this->model_setting_setting->editSetting('cart_to_excel', $this->request->post);
            $this->session->data['success'] = $this->language->get('text_success');
            $this->response->redirect($this->url->link('extension/module/cart_to_excel', 'token=' . $this->session->data['token'], 'SSL'));
        }

        $data['heading_title'] = $this->language->get('heading_title');
        $data['text_edit'] = $this->language->get('text_edit');
        $data['text_enabled'] = $this->language->get('text_enabled');
        $data['text_disabled'] = $this->language->get('text_disabled');
        $data['entry_status'] = $this->language->get('entry_status');
        $data['button_save'] = $this->language->get('button_save');
        $data['button_cancel'] = $this->language->get('button_cancel');
        $data['entry_column_image_width'] = $this->language->get('entry_column_image_width');
        $data['entry_column_name_width'] = $this->language->get('entry_column_name_width');
        $data['entry_column_model_width'] = $this->language->get('entry_column_model_width');
        $data['entry_column_quantity_width'] = $this->language->get('entry_column_quantity_width');
        $data['entry_column_price_width'] = $this->language->get('entry_column_price_width');
        $data['entry_column_total_width'] = $this->language->get('entry_column_total_width');
        $data['entry_image_dimensions'] = $this->language->get('entry_image_dimensions');

        $settings = $this->model_setting_setting->getSetting('cart_to_excel');
        $data['cart_to_excel_column_image_width'] = array_key_exists('cart_to_excel_column_image_width', $settings) ? $settings['cart_to_excel_column_image_width'] : self::DEFAULT_COLUMN_IMAGE_WIDTH;
        $data['cart_to_excel_column_name_width'] = array_key_exists('cart_to_excel_column_name_width', $settings) ? $settings['cart_to_excel_column_name_width'] : self::DEFAULT_COLUMN_NAME_WIDTH;
        $data['cart_to_excel_column_model_width'] = array_key_exists('cart_to_excel_column_model_width', $settings) ? $settings['cart_to_excel_column_model_width'] : self::DEFAULT_COLUMN_MODEL_WIDTH;
        $data['cart_to_excel_column_quantity_width'] = array_key_exists('cart_to_excel_column_quantity_width', $settings) ? $settings['cart_to_excel_column_quantity_width'] : self::DEFAULT_COLUMN_QUANTITY_WIDTH;
        $data['cart_to_excel_column_price_width'] = array_key_exists('cart_to_excel_column_price_width', $settings) ? $settings['cart_to_excel_column_price_width'] : self::DEFAULT_COLUMN_PRICE_WIDTH;
        $data['cart_to_excel_column_total_width'] = array_key_exists('cart_to_excel_column_total_width', $settings) ? $settings['cart_to_excel_column_total_width'] : self::DEFAULT_COLUMN_TOTAL_WIDTH;
        $data['cart_to_excel_image_width'] = array_key_exists('cart_to_excel_image_width', $settings) ? $settings['cart_to_excel_image_width'] : self::DEFAULT_IMAGE_WIDTH;
        $data['cart_to_excel_image_height'] = array_key_exists('cart_to_excel_image_height', $settings) ? $settings['cart_to_excel_image_height'] : self::DEFAULT_IMAGE_HEIGHT;

        foreach ($this->error as $key => $value){
            $data['error_' . $key] = $this->error[$key];
        }

        $data['breadcrumbs'] = array();
        $data['breadcrumbs'][] = array(
            'text' => $this->language->get('text_home'),
            'href' => $this->url->link('common/dashboard', 'token=' . $this->session->data['token'], 'SSL')
        );
        $data['breadcrumbs'][] = array(
            'text' => $this->language->get('text_module'),
            'href' => $this->url->link('module', 'token=' . $this->session->data['token'], 'SSL')
        );
        $data['breadcrumbs'][] = array(
            'text' => $this->language->get('heading_title'),
            'href' => $this->url->link('extension/module/cart_to_excel', 'token=' . $this->session->data['token'], 'SSL')
        );

        $data['action'] = $this->url->link('extension/module/cart_to_excel', 'token=' . $this->session->data['token'], 'SSL');
        $data['cancel'] = $this->url->link('extension', 'token=' . $this->session->data['token'], 'SSL');

        if (isset($this->request->post['cart_to_excel_status'])) {
            $data['cart_to_excel_status'] = $this->request->post['cart_to_excel_status'];
        } else {
            $data['cart_to_excel_status'] = $this->config->get('cart_to_excel_status');
        }

        $data['header'] = $this->load->controller('common/header');
        $data['column_left'] = $this->load->controller('common/column_left');
        $data['footer'] = $this->load->controller('common/footer');

        $this->response->setOutput($this->load->view('extension/module/cart_to_excel.tpl', $data));
    }

    protected function validate() {
        if (!$this->user->hasPermission('modify', 'extension/module/cart_to_excel')) {
            $this->error['warning'] = $this->language->get('error_permission');
        }
        if ((int)$this->request->post['cart_to_excel_image_width'] <= 0 || (int)$this->request->post['cart_to_excel_image_width'] > 200 || (int)$this->request->post['cart_to_excel_image_height'] <= 0 || (int)$this->request->post['cart_to_excel_image_height'] > 200) {
            $this->error['image_dimensions'] = $this->language->get('error_image_dimensions');
        }
        if ($this->error && !isset($this->error['warning'])) {
            $this->error['warning'] = $this->language->get('error_warning');
        }
        return !$this->error;
    }
}