<?php

class ControllerExtensionModuleCartToExcel extends Controller {

    const DEFAULT_STATUS = '1';
    const DEFAULT_COLUMN_IMAGE_WIDTH = 30;
    const DEFAULT_COLUMN_NAME_WIDTH = 100;
    const DEFAULT_COLUMN_MODEL_WIDTH = 30;
    const DEFAULT_COLUMN_QUANTITY_WIDTH = 20;
    const DEFAULT_COLUMN_PRICE_WIDTH = 20;
    const DEFAULT_COLUMN_TOTAL_WIDTH = 20;
    const DEFAULT_IMAGE_WIDTH = 50;
    const DEFAULT_IMAGE_HEIGHT = 50;

    private $error = array();

    public function install() {
        $this->load->language('extension/module/cart_to_excel');
        $this->load->model('setting/extension');
        if ($this->validate()) {
            $this->model_setting_extension->install('cart_to_excel', $this->request->get['extension']);
            $this->load->model('user/user_group');
            $this->model_user_user_group->addPermission($this->user->getGroupId(), 'access', 'extension/module/cart_to_excel' . $this->request->get['extension']);
            $this->model_user_user_group->addPermission($this->user->getGroupId(), 'modify', 'extension/module/cart_to_excel' . $this->request->get['extension']);
            $this->session->data['success'] = $this->language->get('text_success');
            $default_settings = array(
                'module_cart_to_excel_status' => self::DEFAULT_STATUS,
                'module_cart_to_excel_column_image_width' => self::DEFAULT_COLUMN_IMAGE_WIDTH,
                'module_cart_to_excel_column_name_width' => self::DEFAULT_COLUMN_NAME_WIDTH,
                'module_cart_to_excel_column_model_width' => self::DEFAULT_COLUMN_MODEL_WIDTH,
                'module_cart_to_excel_column_quantity_width' => self::DEFAULT_COLUMN_QUANTITY_WIDTH,
                'module_cart_to_excel_column_price_width' => self::DEFAULT_COLUMN_PRICE_WIDTH,
                'module_cart_to_excel_column_total_width' => self::DEFAULT_COLUMN_TOTAL_WIDTH,
                'module_cart_to_excel_image_width' => self::DEFAULT_IMAGE_WIDTH,
                'module_cart_to_excel_image_height' => self::DEFAULT_IMAGE_HEIGHT,
            );
            $this->load->model('setting/setting');
            $this->model_setting_setting->editSetting('module_cart_to_excel', $default_settings);
        }
    }

    public function uninstall() {
        $this->load->language('extension/module/cart_to_excel');
        if ($this->validate()) {
            $this->load->model('setting/extension');
            $this->model_setting_extension->uninstall('cart_to_excel', $this->request->get['extension']);
            $this->load->model('setting/setting');
            $this->model_setting_setting->deleteSetting($this->request->get['extension']);
            $this->session->data['success'] = $this->language->get('text_success');
        }
    }

    public function index() {
        $this->load->language('extension/module/cart_to_excel');
        $this->document->setTitle($this->language->get('heading_title'));
        $this->load->model('setting/setting');
        if (($this->request->server['REQUEST_METHOD'] == 'POST') && $this->validate() && $this->validateFields()) {
            $this->model_setting_setting->editSetting('module_cart_to_excel', $this->request->post);
            $this->session->data['success'] = $this->language->get('text_success');
            $this->response->redirect($this->url->link('extension/module/cart_to_excel', 'user_token=' . $this->session->data['user_token'], 'SSL'));
        }

        $data['heading_title'] = $this->language->get('heading_title');
        $data['text_edit'] = $this->language->get('text_edit');
        $data['text_enabled'] = $this->language->get('text_enabled');
        $data['text_disabled'] = $this->language->get('text_disabled');
        $data['entry_status'] = $this->language->get('entry_status');
        $data['button_save'] = $this->language->get('button_save');
        $data['button_cancel'] = $this->language->get('button_cancel');
        $data['entry_column_image_width'] = $this->language->get('entry_column_image_width');
        $data['entry_column_name_width'] = $this->language->get('entry_column_name_width');
        $data['entry_column_model_width'] = $this->language->get('entry_column_model_width');
        $data['entry_column_quantity_width'] = $this->language->get('entry_column_quantity_width');
        $data['entry_column_price_width'] = $this->language->get('entry_column_price_width');
        $data['entry_column_total_width'] = $this->language->get('entry_column_total_width');
        $data['entry_image_dimensions'] = $this->language->get('entry_image_dimensions');

        $settings = $this->model_setting_setting->getSetting('module_cart_to_excel');
        $data['module_cart_to_excel_column_image_width'] = isset($settings['module_cart_to_excel_column_image_width']) ? $settings['module_cart_to_excel_column_image_width'] : self::DEFAULT_COLUMN_IMAGE_WIDTH;
        $data['module_cart_to_excel_column_name_width'] = isset($settings['module_cart_to_excel_column_name_width']) ? $settings['module_cart_to_excel_column_name_width'] : self::DEFAULT_COLUMN_NAME_WIDTH;
        $data['module_cart_to_excel_column_model_width'] = isset($settings['module_cart_to_excel_column_model_width']) ? $settings['module_cart_to_excel_column_model_width'] : self::DEFAULT_COLUMN_MODEL_WIDTH;
        $data['module_cart_to_excel_column_quantity_width'] = isset($settings['module_cart_to_excel_column_quantity_width']) ? $settings['module_cart_to_excel_column_quantity_width'] : self::DEFAULT_COLUMN_QUANTITY_WIDTH;
        $data['module_cart_to_excel_column_price_width'] = isset($settings['module_cart_to_excel_column_price_width']) ? $settings['module_cart_to_excel_column_price_width'] : self::DEFAULT_COLUMN_PRICE_WIDTH;
        $data['module_cart_to_excel_column_total_width'] = isset($settings['module_cart_to_excel_column_total_width']) ? $settings['module_cart_to_excel_column_total_width'] : self::DEFAULT_COLUMN_TOTAL_WIDTH;
        $data['module_cart_to_excel_image_width'] = isset($settings['module_cart_to_excel_image_width']) ? $settings['module_cart_to_excel_image_width'] : self::DEFAULT_IMAGE_WIDTH;
        $data['module_cart_to_excel_image_height'] = isset($settings['module_cart_to_excel_image_height']) ? $settings['module_cart_to_excel_image_height'] : self::DEFAULT_IMAGE_HEIGHT;

        if (isset($this->error['warning'])) {
            $data['error_warning'] = $this->error['warning'];
        } else {
            $data['error_warning'] = '';
        }

        if (isset($this->error['image_dimensions'])) {
            $data['error_image_dimensions'] = $this->error['image_dimensions'];
        } else {
            $data['error_image_dimensions'] = '';
        }

        if (isset($this->session->data['success'])) {
            $data['success'] = $this->session->data['success'];
            unset($this->session->data['success']);
        } else {
            $data['success'] = '';
        }

        $data['breadcrumbs'] = array();
        $data['breadcrumbs'][] = array(
            'text' => $this->language->get('text_home'),
            'href' => $this->url->link('common/dashboard', 'user_token=' . $this->session->data['user_token'], 'SSL')
        );
        $data['breadcrumbs'][] = array(
            'text' => $this->language->get('text_extension'),
            'href' => $this->url->link('marketplace/extension', 'user_token=' . $this->session->data['user_token'] . '&type=module', true)
        );
        $data['breadcrumbs'][] = array(
            'text' => $this->language->get('heading_title'),
            'href' => $this->url->link('extension/module/cart_to_excel', 'user_token=' . $this->session->data['user_token'], 'SSL')
        );

        $data['action'] = $this->url->link('extension/module/cart_to_excel', 'user_token=' . $this->session->data['user_token'], 'SSL');
        $data['cancel'] = $this->url->link('extension', 'user_token=' . $this->session->data['user_token'], 'SSL');

        if (isset($this->request->post['module_cart_to_excel_status'])) {
            $data['module_cart_to_excel_status'] = $this->request->post['module_cart_to_excel_status'];
        } else {
            $data['module_cart_to_excel_status'] = $this->config->get('module_cart_to_excel_status');
        }

        $data['header'] = $this->load->controller('common/header');
        $data['column_left'] = $this->load->controller('common/column_left');
        $data['footer'] = $this->load->controller('common/footer');

        $this->response->setOutput($this->load->view('extension/module/cart_to_excel', $data));
    }

    protected function validate() {
        if (!$this->user->hasPermission('modify', 'extension/module/cart_to_excel')) {
            $this->error['warning'] = $this->language->get('error_permission');
        }
        return !$this->error;
    }

    protected function validateFields() {
        if ((int)$this->request->post['module_cart_to_excel_image_width'] <= 0
            || (int)$this->request->post['module_cart_to_excel_image_width'] > 200
            || (int)$this->request->post['module_cart_to_excel_image_height'] <= 0
            || (int)$this->request->post['module_cart_to_excel_image_height'] > 200) {
            $this->error['image_dimensions'] = $this->language->get('error_image_dimensions');
        }
        if ($this->error && !isset($this->error['warning'])) {
            $this->error['warning'] = $this->language->get('error_warning');
        }
        return !$this->error;
    }
}