<?php
class ControllerExtensionModuleCartToExcel extends Controller {

    public function index() {
        return $this;
    }

    public function cart() {
        if ($this->config->get('module_cart_to_excel_status') == '1' && ($this->cart->hasProducts() || !empty($this->session->data['vouchers']))) {
            $trigger = 'view/checkout/cart/before';
            $action = new Action('extension/module/cart_to_excel/onEventCartView');
            $this->registry->get('event')->register($trigger, $action);
            $this->load->controller('checkout/cart/index');
            $this->registry->get('event')->unregister($trigger, $action);
            $this->response->setOutput('');
        } else {
            $this->load->controller('checkout/cart/index');
        }
    }

    public function onEventCartView($route, $data) {
        if (is_array($data) && isset($data['products']) && is_array($data['products']) && count($data['products']) > 0) {
            require_once DIR_SYSTEM . 'library/PHPExcel/Classes/PHPExcel.php';
            $objPHPExcel = new PHPExcel();
            $objPHPExcel->getProperties()->setCreator("Cart-To-Excel Module")
                ->setLastModifiedBy("Cart-To-Excel Module")
                ->setTitle("Office 2007 XLSX Document")
                ->setSubject("Office 2007 XLSX Document")
                ->setDescription("Document for Office 2007 XLSX")
                ->setKeywords("office 2007 openxml php")
                ->setCategory("XLSX file");
            $head_style = array(
                'font' => array(
                    'bold' => true,
                    'color' => array('argb' => 'FF000000'),
                    'size' => 12,
                    'name' => 'Cambria'
                ),
                'alignment' => array(
                    'horizontal' => PHPExcel_Style_Alignment::HORIZONTAL_CENTER,
                ),
                'borders' => array(
                    'allborders' => array(
                        'style' => PHPExcel_Style_Border::BORDER_THIN,
                    ),
                ),
            );
            $basic_style = array(
                'font' => array(
                    'bold' => false,
                    'color' => array('argb' => 'FF000000'),
                    'size' => 11,
                    'name' => 'Cambria'
                ),
                'alignment' => array(
                    'horizontal' => PHPExcel_Style_Alignment::HORIZONTAL_CENTER,
                    'vertical' => PHPExcel_Style_Alignment::VERTICAL_CENTER,
                ),
                'borders' => array(
                    'allborders' => array(
                        'style' => PHPExcel_Style_Border::BORDER_THIN,
                    ),
                ),
            );
            $name_style = array(
                'font' => array(
                    'bold' => false,
                    'color' => array('argb' => 'FF000000'),
                    'size' => 11,
                    'name' => 'Cambria'
                ),
                'alignment' => array(
                    'horizontal' => PHPExcel_Style_Alignment::HORIZONTAL_LEFT,
                    'vertical' => PHPExcel_Style_Alignment::VERTICAL_CENTER,
                ),
                'borders' => array(
                    'allborders' => array(
                        'style' => PHPExcel_Style_Border::BORDER_THIN,
                    ),
                ),
            );
            $sheet = $objPHPExcel->setActiveSheetIndex(0);
            $y0 = 2;
            $x0 = 1;
            $allowedColumns = array(
                'column_image' => 'thumb',
                'column_name' => 'name',
                'column_model' => 'model',
                'column_quantity' => 'quantity',
                'column_price' => 'price',
                'column_total' => 'total');
            //Head
            $x = $x0;
            $y = $y0;
            $propsToShow = array();

            $this->load->model('setting/setting');
            $settings = $this->model_setting_setting->getSetting('module_cart_to_excel');
            $this->load->language('checkout/checkout');

            $firstProduct = $data['products'][0];
            foreach ($allowedColumns as $settingsKey => $productKey){
                if (isset($firstProduct[$productKey])){
                    $columnWidth = isset($settings['module_cart_to_excel_' . $settingsKey . '_width']) ? $settings['module_cart_to_excel_' . $settingsKey . '_width'] : 0;
                    if ($columnWidth > 0){
                        $columnName = isset($data[$settingsKey]) ? $data[$settingsKey] : isset($firstProduct[$productKey]) ? $this->language->get($settingsKey) : '';
                        if (!empty($columnName)){
                            $cell = $sheet->getCellByColumnAndRow($x++, $y);
                            $cell->setValue($columnName);
                            $cell->getStyle()->applyFromArray($head_style);
                            $sheet->getColumnDimension($cell->getColumn())->setWidth($columnWidth);
                            $propsToShow[] = $productKey;
                        }
                    }
                }
            }
            $y++;
            //Body
            foreach ($data['products'] as $product) {
                $x = $x0;
                foreach ($product as $productKey => $productValue){
                    if (is_string($productKey) && is_string($productValue) && in_array($productKey, $propsToShow)){
                        if ($productKey == 'thumb'){
                            require_once DIR_SYSTEM . 'library/PHPExcel/Classes/PHPExcel/Worksheet/Drawing.php';
                            $objDrawing = new PHPExcel_Worksheet_Drawing();
                            if (!defined('HTTP_IMAGE')){
                                define('HTTP_IMAGE', HTTP_SERVER . 'image/');
                            }
                            $imageWidth = $this->config->get('module_cart_to_excel_image_width') ;
                            $imageHeight = $this->config->get('module_cart_to_excel_image_height') ;
                            $sheet->getRowDimension($y)->setRowHeight($imageHeight + 2);
                            $objDrawing->setPath(urldecode(str_replace(HTTP_IMAGE, DIR_IMAGE, $productValue)));
                            $objDrawing->setWidth($imageWidth);
                            $objDrawing->setHeight($imageHeight);
                            $objDrawing->setWorksheet($sheet);
                            $coordinates = $sheet->getCellByColumnAndRow($x, $y)->getCoordinate();
                            $objDrawing->setCoordinates($coordinates);
                            $columnWidthInImageUnits = $sheet->getColumnDimensionByColumn($x)->getWidth() * 6.87;
                            $objDrawing->setOffsetX($columnWidthInImageUnits / 2 - $imageWidth / 2);
                            $objDrawing->setOffsetY(10);
                        } else {
                            $sheet->setCellValueByColumnAndRow($x, $y, $productValue);
                            $sheet->getStyleByColumnAndRow($x, $y)->getAlignment()->setWrapText(true);
                        }
                        $sheet->getStyleByColumnAndRow($x, $y)->applyFromArray(isset(${$productKey . '_style'}) ? ${$productKey . '_style'} : $basic_style);
                        if ($productKey == 'name' && in_array('href', $product) && !empty($product['href'])){
                            $url = strip_tags(htmlspecialchars_decode($product['href']));
                            $sheet->getCellByColumnAndRow($x, $y)->getHyperlink()->setUrl($url);
                            $sheet->getCellByColumnAndRow($x, $y)->getHyperlink()->setTooltip($url);
                            $sheet->getStyleByColumnAndRow($x, $y)->applyFromArray([
                                'font' => [
                                    'color' => array('argb' => '000000FF'),
                                    'underline' => 'single'
                                ]
                            ]);
                        }
                        $x++;
                    }
                }
                $y++;
            }
            //Totals
            if (isset($data['totals'])){
                $x = $x0;
                foreach ($data['totals'] as $total) {
                    $sheet->setCellValueByColumnAndRow($x, $y, $total['title']);
                    $sheet->getStyleByColumnAndRow($x, $y)->applyFromArray($head_style);
                    $sheet->getStyleByColumnAndRow($x, $y)->getAlignment()->setWrapText(true);
                    $sheet->setCellValueByColumnAndRow($x + count($propsToShow) - 1, $y, $total['text']);
                    $sheet->getStyleByColumnAndRow($x + count($propsToShow) - 1, $y)->applyFromArray($head_style);
                    $sheet->getStyleByColumnAndRow($x, $y)->getAlignment()->setWrapText(true);
                    $y++;
                }
            }
            $sheet->setTitle(isset($data['heading_title']) ? $data['heading_title'] : 'Shopping Cart');
            $objWriter = PHPExcel_IOFactory::createWriter($objPHPExcel, 'Excel2007');
            header('Content-Type: application/vnd.openxmlformats-officedocument.spreadsheetml.sheet');
            $datetime = new DateTime();
            header('Content-Disposition: attachment;filename="cart_' . $datetime->format('Y-m-d_H-i-s') . '.xlsx"');
            header('Cache-Control: max-age=0');
            $objWriter->save('php://output');
            return true;
        }
    }

    protected function validate() {
        if (!$this->user->hasPermission('modify', 'extension/module/cart_to_excel')) {
            $this->error['warning'] = $this->language->get('error_permission');
        }
        return !$this->error;
    }

}